@@ -528,6 +528,7 @@ var bsAtoms = (this.acr.isMolecular ? null : this.asc.bsAtoms);
 var sym = this.symmetry;
 if (checkRangeNoSymmetry) baseCount = this.noSymmetryCount;
 var atomMax = this.firstAtom + this.noSymmetryCount;
+var bondAtomMin = (this.asc.firstAtomToBond < 0 ? atomMax : this.asc.firstAtomToBond);
 var pttemp =  new JU.P3 ();
 var code = null;
 var d0 = (checkOps ? 0.01 : 0.0001);
@@ -638,7 +639,7 @@ if (ia1 > ia2) {
 var i = ia1;
 ia1 = ia2;
 ia2 = i;
-}if (ia1 != ia2 && (ia1 >= atomMax || ia2 >= atomMax) && this.bondsFound.indexOf (key = "-" + ia1 + "," + ia2) < 0) {
+}if (ia1 != ia2 && (ia1 >= bondAtomMin || ia2 >= bondAtomMin) && this.bondsFound.indexOf (key = "-" + ia1 + "," + ia2) < 0) {
 this.bondsFound.append (key);
 this.asc.addNewBondWithOrder (ia1, ia2, bond.order);
 }}
