@@ -239,7 +239,7 @@ break;
 case J.c.CBK.MEASURE:
 var mystatus = data[3];
 if (mystatus.indexOf ("Picked") >= 0 || mystatus.indexOf ("Sequence") >= 0) this.sendConsoleMessage (strInfo);
- else if (mystatus.indexOf ("Completed") >= 0) this.sendConsoleEcho (strInfo.substring (strInfo.lastIndexOf (",") + 2, strInfo.length - 1));
+ else if (mystatus.indexOf ("Completed") >= 0) this.sendConsoleEcho (strInfo);
 break;
 case J.c.CBK.MESSAGE:
 this.sendConsoleMessage (data == null ? null : strInfo);
