@@ -6,14 +6,14 @@ function () {
 });
 Clazz.overrideMethod (c$, "getInchi", 
 function (vwr, atoms, molData, options) {
-if (atoms == null ? molData == null : atoms.cardinality () == 0) return "";
+if (atoms == null ? molData == null : atoms.isEmpty ()) return "";
 var ret = "";
 try {
 if (options == null) options = "";
 options = JU.PT.rep (JU.PT.rep (options.$replace ('-', ' '), "  ", " ").trim (), " ", " -").toLowerCase ();
 if (options.length > 0) options = "-" + options;
 if (molData == null) molData = vwr.getModelExtract (atoms, false, false, "MOL");
-if (molData.startsWith ("InChI=")) {
+if (Clazz.instanceOf (molData, String) && (molData).startsWith ("InChI=")) {
 {
 ret = (Jmol.inchiToInchiKey ? Jmol.inchiToInchiKey(molData) : "");
 }return ret;
@@ -36,7 +36,7 @@ e = (e.getMessage$ ? e.getMessage$() : e);
 }System.err.println ("InChIJS exception: " + e);
 }
 return ret;
-}, "JV.Viewer,JU.BS,~S,~S");
+}, "JV.Viewer,JU.BS,~O,~S");
 {
 var wasmPath = "/_WASM";
 var es6Path = "/_ES6";
