@@ -1,10 +1,11 @@
 Clazz.declarePackage ("JM.FF");
-Clazz.load (["JM.FF.Calculation"], "JM.FF.UFFVDWCalc", null, function () {
+Clazz.load (["JM.FF.Calculation"], "JM.FF.UFFVDWCalc", ["java.lang.Boolean"], function () {
 c$ = Clazz.declareType (JM.FF, "UFFVDWCalc", JM.FF.Calculation);
 Clazz.overrideMethod (c$, "setData", 
 function (calc, ia, ib, dd) {
 this.a = this.calcs.minAtoms[ia];
 this.b = this.calcs.minAtoms[ib];
+if (this.a.atom.distanceSquared (this.b.atom) > 50.0) return;
 var parA = this.calcs.getParameter (this.a.sType);
 var parB = this.calcs.getParameter (this.b.sType);
 var Xa;
@@ -25,7 +26,7 @@ Xb = parB.dVal[2];
 Db = parB.dVal[3];
 }var Dab = 4.1868 * Math.sqrt (Da * Db);
 var Xab = Math.sqrt (Xa * Xb);
-calc.addLast ( Clazz.newArray (-1, [ Clazz.newIntArray (-1, [ia, ib]),  Clazz.newDoubleArray (-1, [Xab, Dab])]));
+calc.addLast ( Clazz.newArray (-1, [this.iData =  Clazz.newIntArray (-1, [ia, ib]),  Clazz.newDoubleArray (-1, [Xab, Dab]), this.isLoggable (2)]));
 }, "JU.Lst,~N,~N,~N");
 Clazz.overrideMethod (c$, "compute", 
 function (dataIn) {
@@ -40,7 +41,9 @@ this.energy = Dab * term6 * (term6 - 2.0);
 if (this.calcs.gradients) {
 this.dE = Dab * 12.0 * (1.0 - term6) * term6 * term / Xab;
 this.calcs.addForces (this, 2);
-}if (this.calcs.logging) this.calcs.appendLogData (this.calcs.getDebugLine (5, this));
+}if (this.calcs.logging && dataIn[2] === Boolean.TRUE) this.calcs.appendLogData (this.calcs.getDebugLine (5, this));
 return this.energy;
 }, "~A");
+Clazz.defineStatics (c$,
+"MAX_VDW_DIST2", 50);
 });
