@@ -986,7 +986,7 @@ ia = atom.atomPropertyInt (tokWhat);
 break;
 case 1094713368:
 case 1094717448:
-return JU.BSUtil.copy (this.vwr.ms.getConformation (-1, ival - 1, false, null));
+return JU.BSUtil.copy (this.vwr.ms.getConformation (-1, ival, false, null));
 case 1296041985:
 propertyBitSet = atom.atomSymmetry;
 if (propertyBitSet == null) continue;
