@@ -50,7 +50,12 @@ if (c.length > 0) this.infoStr += "\nCentering: " + c;
 this.infoStr += s;
 this.infoStr += "\n";
 }if (unitCellParams == null) unitCellParams = info.get ("unitCellParams");
-if (!JU.SimpleUnitCell.isValid (unitCellParams)) return null;
-return unitCellParams;
+unitCellParams = (JU.SimpleUnitCell.isValid (unitCellParams) ? unitCellParams : null);
+if (unitCellParams == null) {
+this.coordinatesAreFractional = false;
+this.symmetryOperations = null;
+this.cellRange = null;
+this.infoStr = "";
+}return unitCellParams;
 }, "java.util.Map,~A,JS.SpaceGroup");
 });
