@@ -148,9 +148,11 @@ try {
 this.line = (this.reader == null ? this.br.readLine () : this.reader.readNextLine ());
 if (this.line == null) return null;
 if (this.isHeader) {
-if (this.line.startsWith ("#")) this.fileHeader.append (this.line).appendC ('\n');
- else this.isHeader = false;
-}return this.line;
+if (this.line.startsWith ("#")) {
+this.fileHeader.append (this.line).appendC ('\n');
+} else if (this.line.length > 0) {
+this.isHeader = false;
+}}return this.line;
 } catch (e) {
 if (Clazz.exceptionOf (e, Exception)) {
 return null;
