@@ -68,7 +68,7 @@ case 'u':
 var theta = 6.283185307179586 * nt;
 if (this.a1 != 0) v += this.a1 * Math.sin (theta);
 if (this.a2 != 0) v += this.a2 * Math.cos (theta);
-if (JU.Logger.debuggingHigh) JU.Logger.info ("MOD " + ms.id + " " + JU.Escape.e (this.qCoefs) + " axis=" + this.axis + " v=" + v + " csin,ccos=" + this.a1 + "," + this.a2 + " / theta=" + theta);
+if (JU.Logger.debuggingHigh) JU.Logger.info ("MOD " + ms.id + " " + t[0][0] + " " + JU.Escape.e (this.qCoefs) + " axis=" + this.axis + " v=" + v + " csin,ccos=" + this.a1 + "," + this.a2 + " / theta=" + theta);
 break;
 case 'L':
 case 'l':
