@@ -62,7 +62,7 @@ return;
 }this.fullPathName = fileInfo[0];
 this.fileName = fileInfo[Math.min (1, fileInfo.length - 1)];
 this.nameAsGiven = fileInfo[Math.min (2, fileInfo.length - 1)];
-if (!this.nameAsGiven.equals ("zapped") && !this.nameAsGiven.equals ("string")) {
+if (!this.nameAsGiven.equals ("zapped")) {
 this.lastNameAsGiven = this.nameAsGiven;
 this.lastFullPathName = this.fullPathName;
 }}, "~A");
