@@ -185,7 +185,7 @@ return (script == null ? "" : script);
 Clazz.defineMethod (c$, "popStack", 
 function (type) {
 var stack = this.getStack (type);
-var state = (stack.size () > 0 ? stack.remove (stack.size () - 1) : null);
+var state = (stack.size () > 0 ? stack.removeItemAt (stack.size () - 1) : null);
 if (state != null) {
 this.appendState (this.getStack (type == 603984065 ? 4139 : 603984065));
 }this.checkStack (this.getStack (603984065));
